#+TITLE: Writing and organizing literature notes for scientific writing - EmacsConf 2022
#+AUTHOR: Vidianos Giannitsis
#+DATE: December 3, 2022
#+EMAIL: vidianosgiannitsis@gmail.com
#+OPTIONS: toc:nil
#+LaTeX_CLASS_OPTIONS: [bigger]
#+BEAMER_THEME: Copenhagen

* Hello Everyone!

* My second brain
#+ATTR_ORG: :width 600px
[[file:My_second_brain/2022-10-13_22-27-03_screenshot.png]]

* Contents of the talk
- Bibliography management
- Creating literature notes
- Writing literature notes with org-noter
- Adding the literature note to your Zettelkasten
- Writing permanent notes based on the info obtained by the literature
- The organization problem and Zetteldesk, its solution
- Composing the final article

* Bibliography management
Zotero is a bibliography manager that allows you to seamlessly store any article you find on the web to your collection and can then export to .bib for integration with Emacs.

Researching on a topic, I have a long list of articles given by my search engine. Of these, I open every article that has an interesting title and read its abstract. Of these abstracts, I save to Zotero those whose abstract seems relevant to what I am looking for. Of these, I will select a few that are the most interesting and read them in-depth with the process that follows. Zotero is basically a dumpster of everything relevant enough to deserve being saved and it does that well. The real work though happens in Emacs.

* Creating Literature Notes I
 For initializing my literature notes, I have ~org-roam-bibtex-mode~ active on startup and have ~ivy-bibtex-edit-notes~ as my ~ivy-bibtex-default-action~ . This means that when using ~ivy-bibtex~, I can select an article and will be immediately prompted for an org-roam capture template.

#+BEGIN_SRC elisp

  (setq ivy-bibtex-default-action 'ivy-bibtex-edit-notes)

  (ivy-add-actions
   'ivy-bibtex
   '(("p" ivy-bibtex-open-any "Open pdf, url or DOI")))

  (org-roam-bibtex-mode 1)
#+END_SRC
 
* Creating Literature Notes II
Below is the source code for my org-roam reference template

#+BEGIN_SRC elisp

  ("r" "bibliography reference" plain
   "%?"
   :if-new
   (file+head "ref/${citekey}.org" "#+title: ${title}\n
  ,#+filetags: ${entry-type}
  - keywords :: ${keywords}
  - tags :: 

  ,* Analysis of ${entry-type} by ${author}
  :PROPERTIES:
  :URL: ${url}
  :NOTER_DOCUMENT: ${file}  
  :NOTER_PAGE:              
  :END:")
   :unnarrowed t
   :jump-to-captured t)
#+END_SRC

* Demo 1

* My annotation process
** Annotating with org-noter
Org-noter is one of my absolute favourite Emacs packages. It allows you to open a pdf and an org document side by side and do live annotations of the pdf in the org document.

This is in my opinion much better than annotating in the pdf and don't get me started on how bad notes are if they do not mention from which section of the article they are. The fact that it is in org format makes it really powerful and it allows you to only focus on your notes, but also be able to see where in the pdf they refer in a seamless manner. The fact that it can integrate with my capture-template is also great.
** Annotating in English
I always annotate articles I read in English, despite it not being my mother tongue. I highly recommend this as I find translating to be unnecessary mental overhead. When reading an article, I want to pay attention to its contents and translating stuff while reading just moves my attention out of the content.
** Afterthoughts on an article
When finishing an article, I always like to write a mini-abstract of my thoughts on it. This does not contain much, typically how useful I found the stuff mentioned, what exactly was mentioned that matters to me and sometimes also things to look for in the future based on what I read here.

* Adding the note to my Zettelkasten
One of the biggest advantages of my notes being in org format - besides the fact that org is an amazing format - is that I can add the literature note as it was created during the annotating process to my Zettelkasten. Adding a note to your zettelkasten is not about it being in the correct directory structure. It means linking it to other relevant notes.

Typically, when researching for a subject I will have an index for it, which all articles will point to. For better understanding of the article, it also makes sense to link to it every permanent note whose contents were mentioned in the article. In this way, the article enters my network of notes close to other similar notes.

* Demo 2
A fully fledged literature note

* Creating permanent notes from reference material
But if you just link the article to old nodes, you will never obtain new information. For your zettelkasten to truly grow, whenever an article you read contains new information that is not in your zettelkasten, you should create a note about it. In this way, the subject you are researching is not just a bunch of literature notes, but also has a lot of well structured permanent notes, which are in reality the ones you will read when looking back at the subject.

* The organization problem
So, you have read a bunch of articles following the above process. If you are writing any non trivial piece of text, your collection of notes on the subject will not be small by any means. And its also very likely that it is not the only thing that you recently worked on, hence other stuff is cluttering your mind.

Moreover, keep in mind that you need to justify everything you write with citations so you need to remember what each article talks about. A lot of the work needed to write the article is done through these notes and a lot of your manuscript will be these notes. But, you need to combine everything in a coherent way and logical order. This is what my project zetteldesk.el is all about and what I will talk about for the rest of the talk.

* Zetteldesk.el
Zetteldesk is a project whose inception was inspired by "How to take smart notes". Specifically, this quote
#+BEGIN_QUOTE
After a while, you will have developed ideas far enough to decide on a topic to write about. Your topic is now based on what you have, not based on an unfounded idea about what the literature you are about to read might provide. Look through the connections and collect all the relevant notes on this topic (most of the relevant notes will already be in partial order), copy them onto your “desktop” and bring them in order. Look for what is missing and what is redundant. Don’t wait until you have everything together. Rather, try ideas out and give yourself enough time to go back to reading and note-taking to improve your ideas, arguments and their structure.
#+END_QUOTE
In trying to create this "desktop" I created a much more generalized infrastructure which can be used for much more than this. Funnily, when I actually started writing the code, this wasn't even the first thing that was implemented.

** The zetteldesk-desktop
Before I begin, I want to introduce you to the idea of the "desktop" zetteldesk uses. This is essentially a collection of nodes which you want readily available. Using the zetteldesk-add functions you select which these nodes are and using the various filter functions you can select the node you want out of only the ones in your desktop.

* Demo 3

* Composing the final article
By taking notes in this way and ordering them using zetteldesk, it is apparent that a significant part of your work is already done. The notes you took will aid you in your writing and having taken the time to order everything correctly, a coherent and logical connection is bound to happen. You need to write the actual draft, but after all this, that part is trivial. It just includes writing the stuff you see in your desktop in the order you see them and connecting them. Compared to the rest of the process, this requires the least thinking (at least content-wise), yet is the most important as it is the only thing others will see. So you can pay all your attention in making it look good.

* Thanks a lot for your time!

Contact info: Feel free to email me at vidianosgiannitsis@gmail.com

[[Zetteldesk Github][https://github.com/Vidianos-Giannitsis/zetteldesk.el]]

And I will be available for questions in IRC, the pad and the live Q&A which will follow.

See you!
